# Django built-in admin site configuration file
from django.contrib import admin
from models import Category, Department, Status, Project

# We've turned on a lot of stuff here as an example. You should probably pick the options you like...
class ProjectAdmin(admin.ModelAdmin):
	list_display = (		# When we're looking at the Admin's "Project" section, show us these fields in a columnar view
		'id',
		'title',
		'category',
		'priority',
		'status',
		'date_requested',
		'date_modified',
		'date_needed',
		'originator',
		'contact_person',
		'department',
		'is_active',
	)
	list_display_links = (		# When we're looking at the Admin's "Project" section, make these fields links to view *one* project
		'id',
		'title',
	)
	list_filter = (			# When we're looking at the Admin's "Project" section, add a filter widget with these options
		'category',
		'priority',
		'status',
		'date_needed',
		'department'
	)
	list_per_page = 1000		# Show a maximum of 1000 projects per page
	fieldsets = (			# When we're looking at *one* project in the Admin, create fieldsets like this
		(
			'General Information',	# "Legend" of the fieldset
			{
				'fields': (	# These are the fields in the fieldset
					'is_active',
					'title',
					'category',
					'description',
					'date_needed',
					'department',
					'contact_person',
				),
			},
		),
		(
			'ITS Information',
			{
				'fields': (
					'its_contact',
					'priority',
					'status',
					'programmer_assigned',
				),
			},
		),
		(
			'Resources Needed',
			{
				'fields': (
					'hardware_needed',
					'software_needed',
					'people_needed',
				),
				'classes': ('collapse',),	# Assign this class (i.e. CSS class) to the fieldset. In this case, "collapse" is a builtin class that... collapses by default
			},
		),
		(
			'Assessment Information',
			{
				'fields': (
					'cost_estimate',
					'performance_measurement',
				),
				'classes': ('collapse',),
			},
		),
	)
	ordering = ['-id']	# Order descending by ID, by default
	save_on_top = True	# Display the "save" buttons on the top, as well as the bottom
	search_fields=['title','description','hardware_needed','software_needed','people_needed',]	# Let people search against these fields

# Register each model for use with the Admin. Since we want a lot of options for "Project" objects, also register the "ProjectAdmin" class
admin.site.register(Category)
admin.site.register(Department)
admin.site.register(Status)                              
admin.site.register(Project, ProjectAdmin)
